@@ -7,5 +7,7 @@ installdir = os.environ['MESON_INSTALL_PREFIX']
 
 if not os.environ.get('DESTDIR'):
   print('Byte-compiling python modules...')
-  subprocess.call(['pycompile', installdir])
+  subprocess.call(['python', '-m', 'compileall', '-f', '-q', installdir])
+
+  print('Byte-compiling python modules (optimized versions) ...')
   subprocess.call(['python', '-O', '-m', 'compileall', '-f', '-q', installdir])
