@@ -386,18 +386,12 @@ thumb_app_setup_play (ThumbApp *app)
 	GstElement *play;
 	GstElement *audio_sink, *video_sink;
 	GstRegistry *registry;
-        const char *blacklisted_plugins[] = {
-          "vaapidecodebin",
-          "vaapidecode",
-          "vaapimpeg2dec",
-          "vaapih264dec",
-          "vaapivc1dec",
-          "vaapivp8dec",
-          "vaapivp9dec",
-          "vaapih265dec",
-          "bmcdec"
-        };
-        guint i;
+	const char *blacklisted_plugins[] = {
+	  "bmcdec",
+	  "vaapi",
+	  "video4linux2"
+	};
+	guint i;
 
 	play = gst_element_factory_make ("playbin", "play");
 	audio_sink = gst_element_factory_make ("fakesink", "audio-fake-sink");
@@ -419,12 +413,11 @@ thumb_app_setup_play (ThumbApp *app)
 	registry = gst_registry_get ();
 
 	for (i = 0; i < G_N_ELEMENTS (blacklisted_plugins); i++) {
-		GstPluginFeature *feature =
-			gst_registry_find_feature (registry,
-						   blacklisted_plugins[i],
-						   GST_TYPE_ELEMENT_FACTORY);
-		if (feature)
-			gst_registry_remove_feature (registry, feature);
+		GstPlugin *plugin =
+			gst_registry_find_plugin (registry,
+						  blacklisted_plugins[i]);
+		if (plugin)
+			gst_registry_remove_plugin (registry, plugin);
 	}
 }
 
